@@ -1,19 +1,28 @@
-#include "distances-details.h"
+#include "details.h"
 
 #include <cmath> // std::sqrt
 
-#include "../utils/utils.h" // envelope_cpp, kahan_sum
+#include "../utils/SurrogateMatrix.h"
+#include "../utils/utils.h" // envelope_cpp, kahan_sum, id_t
 
 namespace dtwclust {
 
 // thread-safe
-double lbi_core(const double * const x, const double * const y,
-                const int length, const unsigned int window_size, const int p,
-                const double * const lower_envelope, const double * const upper_envelope,
-                double * const L2, double * const U2, double * const H, double * const LB)
+double lbi_core(const SurrogateMatrix<const double>& x,
+                const SurrogateMatrix<const double>& y,
+                const unsigned int window_size,
+                const int p,
+                const SurrogateMatrix<const double>& lower_envelope,
+                const SurrogateMatrix<const double>& upper_envelope,
+                SurrogateMatrix<double>& L2,
+                SurrogateMatrix<double>& U2,
+                SurrogateMatrix<double>& H,
+                SurrogateMatrix<double>& LB)
 {
+    id_t length = x.nrow();
     double lb = 0;
-    for (int i = 0; i < length; i++) {
+
+    for (id_t i = 0; i < length; i++) {
         if (x[i] > upper_envelope[i]) {
             H[i] = upper_envelope[i];
             LB[i] = x[i] - upper_envelope[i];
@@ -28,9 +37,10 @@ double lbi_core(const double * const x, const double * const y,
         }
         if (p > 1) LB[i] *= LB[i];
     }
-    envelope_cpp(H, length, window_size * 2 + 1, L2, U2);
+
+    envelope_cpp(H, window_size * 2 + 1, L2, U2);
     double temp = 0;
-    for (int i = 0; i < length; i++) {
+    for (id_t i = 0; i < length; i++) {
         if (y[i] > U2[i])
             temp = y[i] - U2[i];
         else if (y[i] < L2[i])
@@ -40,7 +50,8 @@ double lbi_core(const double * const x, const double * const y,
         if (p > 1) temp *= temp;
         LB[i] += temp;
     }
-    lb = kahan_sum(LB, length);
+
+    lb = kahan_sum(LB);
     if (p > 1) lb = std::sqrt(lb);
     return lb;
 }
