@@ -7,3 +7,7 @@ source("system/fuzzy.R", TRUE)
 source("system/hierarchical.R", TRUE)
 source("system/partitional.R", TRUE)
 source("system/comparisons.R", TRUE)
+
+test_that("The RNGkind was not affected by dtwclust.", {
+    expect_identical(RNGkind()[1L], default_rngkind)
+})
